[−][src]Trait rel_ptr::MetaData
A trait to abstract over the sizedness of types, and to access metadata about a type
If Custom DST lands and stablizes,
then it will replace MetaData
Associated Types
Loading content...Required methods
fn decompose(this: &mut Self) -> (*mut u8, Self::Data)
decompose a type into a thin pointer and some metadata
unsafe fn compose(ptr: *mut u8, data: Self::Data) -> *mut Self
recompose a type from a thin pointer and some metadata
it is guarenteed that the metadata is
MetaData::Data::default()ifptr == null- generated from
MetaData::decompose